@@ -17,7 +17,6 @@ try:
 except:
     print 'can not import motor '
 
-
 session_id = lambda :sha1('%s%s'%(os.urandom(16),time.time())).hexdigest()
 
 class ContextHandler(RequestHandler):
@@ -28,9 +27,10 @@ class ContextHandler(RequestHandler):
     def session(self,key,val=None):
         _id = self.get_secure_cookie('session_id',None)
         if not _id:
-            self.set_secure_cookie('session_id',session_id())
-        return get_context().session(_id,key,val)
+            _id = session_id()
+            self.set_secure_cookie('session_id',_id)
 
+        return get_context().redis_session(_id,key,val) if __conf__.REDIS_SESSION else get_context().session(_id,key,val)
 
 class LogicContext(object):
     """
@@ -51,6 +51,9 @@ class LogicContext(object):
         return self
     
     def __exit__(self,exc_type, exc_value, trackback):
+        if self._session:
+            self._session.update(dict(_id=self._session_id),{'$set': {'data':self._session_val}})
+        
         self._thread_local.contexts.remove(self)
         if self._db_conn:
             self._db_conn.disconnect()
@@ -64,7 +67,7 @@ class LogicContext(object):
     def get_mongo(self,name=None):
         name = name or __conf__.DB_NAME
         if not self._db_conn:
-            self._db_conn = Connection(host = self._db_host, network_timeout= __conf__.SOCK_TIMEOUT)
+            self._db_conn = Connection(host = __conf__.DB_HOST, network_timeout= __conf__.SOCK_TIMEOUT)
 
         return self._db_conn[name]
 
@@ -72,25 +75,23 @@ class LogicContext(object):
         """ 非阻塞的pympongo 支持，需要安装motor """
         name = name or __conf__.DB_NAME
         if not self._sync_db:
-            client = motor.MotorClient(host = self._db_host).open_sync()
-            self._sync_db = client[name]
+            self._sync_db = motor.MotorClient(host = __conf__.DB_HOST).open_sync()[name]
 
         return self._sync_db
     
     def session(self,_id,key,val=None,expire = None):
         if not self._session:
             self._session = self.get_mongo('session')['session']
+            self._session_val = (self._session.find_one(dict(_id=_id)) or {}).get('data',{})
+            self._session_id = _id
 
-        dt = self._session.find_one(dict(_id=_id)) or {}
-        if not val: return dt.get('data',{}).get(key)
+        if not val: return self._session_val.get(key)
+        if not self._session_val:self._session.insert(dict(_id=_id,data=dict(key=val)))
         
-        if dt:
-            self._session.update(dict(_id=_id),{'$set':{'data.'+key:val}})
-        else:
-            self._session.insert(dict(_id=_id,data=dict(key=val)))
-        return val
-
-
+        self._session_val[key]=val
+        
+    def redis_session(self,_id,key,val=None):
+        return self.get_redis().hget(_id,key) if val else self.get_redis().hset(_id,key,val)
 
     @classmethod
     def get_context(cls):
